==> haskell-parsec-numbers-0.1.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parsec-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parsec-numbers
version:              0.1.0
visibility:           public
id:                   parsec-numbers-0.1.0-2392H3pf2rWAfyis9FX1p7
key:                  parsec-numbers-0.1.0-2392H3pf2rWAfyis9FX1p7
license:              BSD-3-Clause
maintainer:           chr.maeder@web.de
author:               chr.maeder@web.de
stability:            experimental
synopsis:             Utilities for parsing numbers from strings
description:
    parsec-numbers provides the number parsers without the need to
    use a large (and unportable) token parser

category:             Parsing
abi:                  ffe99a3fe4a7026bded6777c702b06ad
exposed:              True
exposed-modules:      Text.ParserCombinators.Parsec.Number
import-dirs:          /usr/lib/ghc-8.8.3/site-local/parsec-numbers-0.1.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/parsec-numbers-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/parsec-numbers-0.1.0
hs-libraries:         HSparsec-numbers-0.1.0-2392H3pf2rWAfyis9FX1p7
depends:              base-4.13.0.0 parsec-3.1.14.0
haddock-interfaces:
    /usr/share/doc/haskell-parsec-numbers/html/parsec-numbers.haddock

haddock-html:         /usr/share/doc/haskell-parsec-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsec-numbers-0.1.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parsec-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parsec-numbers
version:              0.1.0
visibility:           public
id:                   parsec-numbers-0.1.0-KHAU6BqlRgZJQAnbr1bRo9
key:                  parsec-numbers-0.1.0-KHAU6BqlRgZJQAnbr1bRo9
license:              BSD-3-Clause
maintainer:           chr.maeder@web.de
author:               chr.maeder@web.de
stability:            experimental
synopsis:             Utilities for parsing numbers from strings
description:
    parsec-numbers provides the number parsers without the need to
    use a large (and unportable) token parser

category:             Parsing
abi:                  43bcadfd322d7767699ee82eb3743783
exposed:              True
exposed-modules:      Text.ParserCombinators.Parsec.Number
import-dirs:          /usr/lib/ghc-8.10.1/site-local/parsec-numbers-0.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/parsec-numbers-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/parsec-numbers-0.1.0
hs-libraries:         HSparsec-numbers-0.1.0-KHAU6BqlRgZJQAnbr1bRo9
depends:              base-4.14.0.0 parsec-3.1.14.0
haddock-interfaces:
    /usr/share/doc/haskell-parsec-numbers/html/parsec-numbers.haddock

haddock-html:         /usr/share/doc/haskell-parsec-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
